@@ -1,5 +1,5 @@
 import sys
 print ("locales = \"\"\"")
 for i in sys.argv[1:]:
-    print i
+    print (i)
 print ("\"\"\".strip().split(\"\\n\")")
